@@ -13,8 +13,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from horizon import tables
 
 from manila_ui.api import manila
@@ -31,7 +31,7 @@ class CreateShareGroupType(tables.LinkAction):
 class DeleteShareGroupType(tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Share Group Type",
             u"Delete Share Group Types",
             count
@@ -39,7 +39,7 @@ class DeleteShareGroupType(tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Deleted Share Group Type",
             u"Deleted Share Group Types",
             count
